@@ -1,11 +1,11 @@
-.First.lib <-
-function (lib, pkg) 
+.onLoad <-
+function (libname, pkgname) 
 {
     if (testrwm()) {
         setwd(.UserDirectory)
         cat(paste("Current directory:", .UserDirectory), fill = TRUE)
     }
-    else cat("Please run `initrwm()`. Then quit R and reload it", 
+    else cat("Please run `rwmInit()`.", 
         fill = TRUE)
 }
 
